==> myfaces-core-assembly-2.0.25-src.zip: myfaces-core-module-2.0.25/impl/src/test/java/org/apache/myfaces/view/facelets/pss/acid/managed/ResourceDependencyBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.pss.acid.managed;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

/**
 *
 * @author Leonardo Uribe
 */
@ManagedBean(name="resourceDependencyBean")
@SessionScoped
public class ResourceDependencyBean
{
    private boolean includeContent;
    
    /**
     * @return the includeContent
     */
    public boolean isIncludeContent()
    {
        return includeContent;
    }

    /**
     * @param includeContent the includeContent to set
     */
    public void setIncludeContent(boolean includeContent)
    {
        this.includeContent = includeContent;
    }
    
    public void toggleContent()
    {
        this.includeContent =  !this.includeContent;
    }
}

==> myfaces-core-assembly-3.0.2-src.zip: myfaces-core-module-3.0.2/impl/src/test/java/org/apache/myfaces/view/facelets/pss/acid/managed/ResourceDependencyBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.pss.acid.managed;

import jakarta.faces.bean.ManagedBean;
import jakarta.faces.bean.SessionScoped;

/**
 *
 * @author Leonardo Uribe
 */
@ManagedBean(name="resourceDependencyBean")
@SessionScoped
public class ResourceDependencyBean
{
    private boolean includeContent;
    
    /**
     * @return the includeContent
     */
    public boolean isIncludeContent()
    {
        return includeContent;
    }

    /**
     * @param includeContent the includeContent to set
     */
    public void setIncludeContent(boolean includeContent)
    {
        this.includeContent = includeContent;
    }
    
    public void toggleContent()
    {
        this.includeContent =  !this.includeContent;
    }
}
